==> haskell-hspec-smallcheck-0.5.3-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-Hc545nTbeDm4hjoDN5zr9V
key:                  hspec-smallcheck-0.5.3-Hc545nTbeDm4hjoDN5zr9V
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  4d22ca7397a23cd3b687c83d72427212
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-Hc545nTbeDm4hjoDN5zr9V
depends:
    HUnit-1.6.2.0-GnO9wO3IZ0dFnUT6z8aFmA base-4.17.2.1
    call-stack-0.4.0-GLZYnk9HL8J8EgKDjlcntK
    hspec-core-2.11.0-6J6Gnk99DGRCGsQpNUyAoK
    smallcheck-1.2.1.1-57mCCiscAwD24EgjEByyhI

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.3-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-B6bxXIv4VY5J0Ui4lFEnkJ
key:                  hspec-smallcheck-0.5.3-B6bxXIv4VY5J0Ui4lFEnkJ
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  1ab880e936fbb5a2980a6862dd516011
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-B6bxXIv4VY5J0Ui4lFEnkJ
depends:
    HUnit-1.6.2.0-GnO9wO3IZ0dFnUT6z8aFmA base-4.17.2.1
    call-stack-0.4.0-GLZYnk9HL8J8EgKDjlcntK
    hspec-core-2.11.0-81xu7oQKWO3LLNddi7Yvwr
    smallcheck-1.2.1.1-6jISRyHbzqvEZRF3yrI46p

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
